@@ -23,7 +23,6 @@
 
 // Qt includes
 #include <QPointF>
-#include <QSizeF>
 #include <QGraphicsPixmapItem>
 
 // Local includes
@@ -63,13 +62,13 @@ public:
      * Standard QGI advance function.
      * @param phase The advance phase
      */
-    virtual void advance(int phase);
+    void advance(int phase) override;
 
     /**
      * Retrieve the type of QGI. This item is UserType+3
      * @return The type of item.
      */
-    virtual int type() const {return QGraphicsItem::UserType + 3;}
+    int type() const override {return QGraphicsItem::UserType + 3;}
 
     /**
      * Retrieve the user defined sprite number (i.e. which PixmapSprite)
@@ -82,7 +81,7 @@ public:
      * a new theme or a theme size change occurs. This object needs to
      * resize and redraw then.
      */
-    virtual void changeTheme();
+    void changeTheme() override;
 
     /**
      * Choose a pixmap frame of this sprite. If the setting is forced a
